import os
import time
import uuid

import pytest as pytest

from iomete_sdk.spark import SparkJobApiClient
from iomete_sdk.api_utils import ClientError

TEST_TOKEN = "YOUR_TOKEN_HERE"
HOST = "YOUR_DATAPLANE_HOST_HERE"  # https://dataplane-endpoint.example.com

SPARK_VERSION = "3.2.1"


def random_job_name():
    return f"test-job-{uuid.uuid4().hex}"


@pytest.fixture
def create_payload() -> dict:
    return {
        "name": random_job_name(),
        "template": {
            "sparkVersion": SPARK_VERSION,
            "mainApplicationFile": "local:///opt/spark/examples/jars/spark-examples_2.12-3.2.1-iomete.jar",
            "mainClass": "org.apache.spark.examples.SparkPi",
            "arguments": ["10"]
        }
    }


@pytest.fixture
def job_client():
    return SparkJobApiClient(
        host=HOST,
        api_key=TEST_TOKEN,
    )


def test_create_job_without_name_raise_400(job_client, create_payload):
    payload_without_name = {}

    with pytest.raises(ClientError) as err:
        response = job_client.create_job(payload=payload_without_name)

    assert err.value.status == 400


def test_create_job_successful(job_client, create_payload):
    response = job_client.create_job(payload=create_payload)

    assert response["name"] == create_payload["name"]
    assert response["id"] is not None

    # clean up
    job_client.delete_job_by_id(job_id=response["id"])


def test_update_job(job_client, create_payload):
    # create job
    job_create_response = job_client.create_job(payload=create_payload)

    cron_schedule = "0 0 */1 * *"

    # update job
    update_payload = job_create_response.copy()
    update_payload["schedule"] = cron_schedule
    job_update_response = job_client.update_job(job_id=job_create_response["id"], payload=update_payload)

    assert job_update_response["schedule"] == cron_schedule
    assert job_update_response["jobType"] == "SCHEDULED"
    assert job_update_response["name"] == job_create_response["name"]
    assert job_update_response["id"] == job_create_response["id"]

    # clean up
    job_client.delete_job_by_id(job_id=job_update_response["id"])


def test_get_jobs(job_client):
    response = job_client.get_jobs()

    assert len(response["items"]) > 0

    job = response["items"][0]
    assert job["id"] is not None


def test_get_job_by_id(job_client, create_payload):
    # create job
    job = job_client.create_job(payload=create_payload)

    # check job is created
    response = job_client.get_job_by_id(job_id=job["id"])

    assert response["item"] is not None
    assert response["permissions"] is not None

    job = response["item"]
    assert job["name"] == create_payload["name"]
    assert job["id"] is not None

    # clean up
    job_client.delete_job_by_id(job_id=job["id"])


def test_delete_job_by_id(job_client, create_payload):
    # create job
    job = job_client.create_job(payload=create_payload)

    # check job is created
    response = job_client.get_job_by_id(job_id=job["id"])
    assert response["item"]["name"] == create_payload["name"]

    # delete job
    job_client.delete_job_by_id(job_id=job["id"])

    # check job is deleted
    with pytest.raises(ClientError) as err:
        job_client.get_job_by_id(job_id=job["id"])
    assert err.value.status == 404
    assert err.value.content["errorCode"] == "NOT_FOUND"


def test_get_job_runs(job_client, create_payload):
    # create job
    job = job_client.create_job(payload=create_payload)

    # check job is created
    response = job_client.get_job_runs(job_id=job["id"])

    # should be empty run list
    assert response == []

    # clean up
    job_client.delete_job_by_id(job_id=job["id"])


def test_submit_job_run(job_client, create_payload):
    # create job
    job = job_client.create_job(payload=create_payload)

    # submit job run
    response = job_client.submit_job_run(job_id=job["id"], payload={})

    run_id = response["id"]

    assert run_id is not None
    assert response["jobId"] == job["id"]

    # sleep 5 seconds before cleaning up
    time.sleep(5)

    # clean up
    job_client.cancel_job_run(job_id=job["id"], run_id=run_id)
    job_client.delete_job_by_id(job_id=job["id"])



import logging
from dataclasses import dataclass
from typing import List

from iomete_sdk.api_utils import ClientError, APIUtils
from iomete_sdk.security.policy_models import AccessPolicyView, RowFilterPolicyView, DataMaskPolicyView

DATA_SECURITY_ENDPOINT = "/api/v1/data-security"


@dataclass
class DataSecurityApiClient:
    logger = logging.getLogger('DataSecurityApiClient')

    host: str
    api_key: str

    data_security_endpoint: str = None
    api_utils: APIUtils = None

    def __post_init__(self):
        self.api_utils = APIUtils(self.api_key)

        self.logger.debug(f"Host: {self.host}")
        self.data_security_endpoint = self.host + DATA_SECURITY_ENDPOINT

    def create_access_policy(self, policy: AccessPolicyView) -> AccessPolicyView:
        data = self.api_utils.call(method="POST",
                                   url=f"{self.data_security_endpoint}/access/policy",
                                   payload=policy.to_dict())

        return AccessPolicyView.from_dict(data)

    def get_access_policies(self) -> List[AccessPolicyView]:
        data = self.api_utils.call(method="GET",
                                   url=f"{self.data_security_endpoint}/access/policy")

        return [AccessPolicyView.from_dict(policy) for policy in data]

    def get_access_policy_by_name(self, policy_name: str) -> AccessPolicyView:
        data = self.api_utils.call(method="GET",
                                   url=f"{self.data_security_endpoint}/access/policy/name/{policy_name}")

        return AccessPolicyView.from_dict(data)

    def get_access_policy_by_id(self, policy_id: int) -> AccessPolicyView:
        data = self.api_utils.call(method="GET",
                                   url=f"{self.data_security_endpoint}/access/policy/{policy_id}")

        return AccessPolicyView.from_dict(data)

    def update_access_policy_by_name(self, policy_name: str, policy: AccessPolicyView) -> AccessPolicyView:
        data = self.api_utils.call(method="PUT",
                                   url=f"{self.data_security_endpoint}/access/policy/name/{policy_name}",
                                   payload=policy.to_dict())

        return AccessPolicyView.from_dict(data)

    def update_access_policy_by_id(self, policy_id: int, policy: AccessPolicyView) -> AccessPolicyView:
        data = self.api_utils.call(method="PUT",
                                   url=f"{self.data_security_endpoint}/access/policy/{policy_id}",
                                   payload=policy.to_dict())

        return AccessPolicyView.from_dict(data)

    def delete_access_policy_by_id(self, policy_id: int):
        self.api_utils.call(method="DELETE",
                            url=f"{self.data_security_endpoint}/access/policy/{policy_id}")

    def create_filter_policy(self, policy: RowFilterPolicyView) -> RowFilterPolicyView:
        data = self.api_utils.call(method="POST",
                                   url=f"{self.data_security_endpoint}/filter/policy",
                                   payload=policy.to_dict())

        return RowFilterPolicyView.from_dict(data)

    def get_filter_policies(self) -> List[RowFilterPolicyView]:
        data = self.api_utils.call(method="GET",
                                   url=f"{self.data_security_endpoint}/filter/policy")

        return [RowFilterPolicyView.from_dict(policy) for policy in data]

    def get_filter_policy_by_name(self, policy_name: str) -> RowFilterPolicyView:
        data = self.api_utils.call(method="GET",
                                   url=f"{self.data_security_endpoint}/filter/policy/name/{policy_name}")

        return RowFilterPolicyView.from_dict(data)

    def get_filter_policy_by_id(self, policy_id: int) -> RowFilterPolicyView:
        data = self.api_utils.call(method="GET",
                                   url=f"{self.data_security_endpoint}/filter/policy/{policy_id}")

        return RowFilterPolicyView.from_dict(data)

    def update_filter_policy_by_name(self, policy_name: str, policy: RowFilterPolicyView) -> RowFilterPolicyView:
        data = self.api_utils.call(method="PUT",
                                   url=f"{self.data_security_endpoint}/filter/policy/name/{policy_name}",
                                   payload=policy.to_dict())

        return RowFilterPolicyView.from_dict(data)

    def update_filter_policy_by_id(self, policy_id: int, policy: RowFilterPolicyView) -> RowFilterPolicyView:
        data = self.api_utils.call(method="PUT",
                                   url=f"{self.data_security_endpoint}/filter/policy/{policy_id}",
                                   payload=policy.to_dict())

        return RowFilterPolicyView.from_dict(data)

    def delete_filter_policy_by_id(self, policy_id: int):
        self.api_utils.call(method="DELETE",
                            url=f"{self.data_security_endpoint}/filter/policy/{policy_id}")

    def create_masking_policy(self, policy: DataMaskPolicyView) -> DataMaskPolicyView:
        data = self.api_utils.call(method="POST",
                                   url=f"{self.data_security_endpoint}/mask/policy",
                                   payload=policy.to_dict())

        return DataMaskPolicyView.from_dict(data)

    def get_masking_policies(self) -> List[DataMaskPolicyView]:
        data = self.api_utils.call(method="GET",
                                   url=f"{self.data_security_endpoint}/mask/policy")

        return [DataMaskPolicyView.from_dict(policy) for policy in data]

    def get_masking_policy_by_name(self, policy_name: str) -> DataMaskPolicyView:
        data = self.api_utils.call(method="GET",
                                   url=f"{self.data_security_endpoint}/mask/policy/name/{policy_name}")

        return DataMaskPolicyView.from_dict(data)

    def get_masking_policy_by_id(self, policy_id: int) -> DataMaskPolicyView:
        data = self.api_utils.call(method="GET",
                                   url=f"{self.data_security_endpoint}/mask/policy/{policy_id}")

        return DataMaskPolicyView.from_dict(data)

    def update_masking_policy_by_name(self, policy_name: str, policy: DataMaskPolicyView) -> DataMaskPolicyView:
        data = self.api_utils.call(method="PUT",
                                   url=f"{self.data_security_endpoint}/mask/policy/name/{policy_name}",
                                   payload=policy.to_dict())

        return DataMaskPolicyView.from_dict(data)

    def update_masking_policy_by_id(self, policy_id: int, policy: DataMaskPolicyView) -> DataMaskPolicyView:
        data = self.api_utils.call(method="PUT",
                                   url=f"{self.data_security_endpoint}/mask/policy/{policy_id}",
                                   payload=policy.to_dict())

        return DataMaskPolicyView.from_dict(data)

    def delete_masking_policy_by_id(self, policy_id: int):
        self.api_utils.call(method="DELETE",
                            url=f"{self.data_security_endpoint}/mask/policy/{policy_id}")



import unittest

from iomete_sdk.api_utils import ClientError
from iomete_sdk.security import DataSecurityApiClient
from iomete_sdk.security.policy_models import AccessPolicyView, DataMaskPolicyView, RowFilterPolicyView, \
    DataMaskPolicyItem, RowFilterPolicyItem, AccessPolicyResource, AccessType, AccessPolicyItem, DataMaskPolicyResource, \
    RowFilterPolicyResource, ValidityPeriod, ResourceInclusionType

# Replace with your own token and host
TEST_TOKEN = "YOUR_TOKEN_HERE"
HOST = "YOUR_DATAPLANE_HOST_HERE"  # https://dataplane-endpoint.example.com


class TestDataSecurityApiClient(unittest.TestCase):
    def setUp(self):
        self.client = DataSecurityApiClient(
            host=HOST,
            api_key=TEST_TOKEN,
        )

    def test_access_policies(self):
        # Create a policy
        policy_name = "iomete-sdk-automated-access-policy"
        new_policy = AccessPolicyView(
            name=policy_name,
            description="iomete-sdk-automated-access-policy",
            resources=[
                AccessPolicyResource(
                    databases=["test_db"],
                    tables=["test_tbl"],
                    columns=["*"]
                )
            ],
            allow_policy_items=[
                AccessPolicyItem(
                    accesses=[AccessType.SELECT, AccessType.UPDATE],
                    users=['{USER}'])
            ]
        )
        created_policy = self.client.create_access_policy(new_policy)

        # Verify the created policy
        self.assertEqual(created_policy.name, policy_name)

        # Retrieve created policy
        existing_policy = self.client.get_access_policy_by_name(policy_name)

        # Update the policy
        updated_policy = existing_policy
        updated_policy.description = 'updated'
        updated_policy = self.client.update_access_policy_by_name(policy_name, updated_policy)

        # Verify the updated policy
        self.assertEqual(updated_policy.description, 'updated')

        # Delete the policy
        self.client.delete_access_policy_by_id(updated_policy.id)

        # Verify the policy is deleted
        with self.assertRaises(ClientError):
            self.client.get_access_policy_by_name(policy_name)

    def test_data_mask_policies(self):
        # Create a policy
        policy_name = "iomete-sdk-automated-masking-policy"
        new_policy = DataMaskPolicyView(
            name=policy_name,
            description="iomete-sdk-automated-masking-policy",
            resources=[
                DataMaskPolicyResource(
                    database="test_db",
                    table="test_tbl",
                    column="test_col"
                )
            ],
            data_mask_policy_items=[
                DataMaskPolicyItem(
                    data_mask_type="MASK_SHOW_LAST_4",
                    users=["{USER}"]
                )]
        )
        created_policy = self.client.create_masking_policy(new_policy)

        # Verify the created policy
        self.assertEqual(created_policy.name, policy_name)

        # Retrieve created policy
        existing_policy = self.client.get_masking_policy_by_name(policy_name)

        # Update the policy
        updated_policy = existing_policy
        updated_policy.description = 'updated'
        updated_policy = self.client.update_masking_policy_by_name(policy_name, updated_policy)

        # Verify the updated policy
        self.assertEqual(updated_policy.description, 'updated')

        # Delete the policy
        self.client.delete_masking_policy_by_id(updated_policy.id)

        # Verify the policy is deleted
        with self.assertRaises(ClientError):
            self.client.get_masking_policy_by_id(updated_policy.id)

    def test_row_filter_policies(self):
        # Create a policy
        policy_name = "iomete-sdk-automated-row-filter-policy"
        new_policy = RowFilterPolicyView(
            name=policy_name,
            description="iomete-sdk-automated-masking-policy",
            resources=[
                RowFilterPolicyResource(
                    database="test_db",
                    table="test_tbl"
                )
            ],
            row_filter_policy_items=[
                RowFilterPolicyItem(
                    filter_expr="1 == 1",
                    users=["{USER}"],
                )]
        )
        created_policy = self.client.create_filter_policy(new_policy)

        # Verify the created policy
        self.assertEqual(created_policy.name, policy_name)

        # Retrieve created policy
        existing_policy = self.client.get_filter_policy_by_name(policy_name)

        # Update the policy
        updated_policy = existing_policy
        updated_policy.description = 'updated'
        updated_policy = self.client.update_filter_policy_by_name(policy_name, updated_policy)

        # Verify the updated policy
        self.assertEqual(updated_policy.description, 'updated')

        # Delete the policy
        self.client.delete_filter_policy_by_id(updated_policy.id)

        # Verify the policy is deleted
        with self.assertRaises(ClientError):
            self.client.get_filter_policy_by_id(updated_policy.id)

    def test_empty_access_policies(self):
        # Attempt to create a policy with no values
        policy_name = "empty-access-policy"
        new_policy = AccessPolicyView(
            name=policy_name,
            description="empty policy",
            resources=[],
            allow_policy_items=[]
        )
        with self.assertRaises(ClientError):
            self.client.create_access_policy(new_policy)

    def test_access_policies_multiple_users(self):
        # Create a policy with multiple users
        policy_name = "multi-user-access-policy"
        new_policy = AccessPolicyView(
            name=policy_name,
            description="policy for multiple users",
            resources=[
                AccessPolicyResource(
                    databases=["test_db"],
                    tables=["test_tbl"],
                    columns=["test_col"],
                    columns_inclusion_type=ResourceInclusionType.EXCLUDE
                )
            ],
            allow_policy_items=[
                AccessPolicyItem(
                    accesses=[AccessType.SELECT, AccessType.UPDATE],
                    users=["{USER}", "{OWNER}"])
            ]
        )
        created_policy = self.client.create_access_policy(new_policy)

        # Verify the created policy
        self.assertEqual(created_policy.name, policy_name)

        # Retrieve created policy
        existing_policy = self.client.get_access_policy_by_name(policy_name)

        # Verify the policy has multiple users
        self.assertEqual(len(existing_policy.allow_policy_items[0].users), 2)
        self.assertEqual(existing_policy.resources[0].columns_inclusion_type, ResourceInclusionType.EXCLUDE)

        # Delete the policy
        self.client.delete_access_policy_by_id(existing_policy.id)

    def test_invalid_datamask_policies(self):
        # Attempt to create a policy with invalid mask type
        policy_name = "invalid-datamask-policy"
        new_policy = DataMaskPolicyView(
            name=policy_name,
            description="invalid datamask policy",
            resources=[
                DataMaskPolicyResource(
                    database="test_db",
                    table="test_tbl",
                    column="test_col"
                )
            ],
            data_mask_policy_items=[
                DataMaskPolicyItem(
                    data_mask_type="INVALID_MASK_TYPE",
                    users=["{USER}"]
                )]
        )
        with self.assertRaises(ClientError):
            self.client.create_masking_policy(new_policy)

    def test_row_filter_policies_complex_expr(self):
        # Create a policy with complex filter expression
        policy_name = "complex-row-filter-policy"
        new_policy = RowFilterPolicyView(
            name=policy_name,
            description="policy with complex filter expression",
            resources=[
                RowFilterPolicyResource(
                    database="test_db",
                    table="test_tbl"
                )
            ],
            row_filter_policy_items=[
                RowFilterPolicyItem(
                    filter_expr="(1 == 1) AND (2 > 1)",
                    users=["{USER}"],
                )]
        )
        created_policy = self.client.create_filter_policy(new_policy)

        # Verify the created policy
        self.assertEqual(created_policy.name, policy_name)

        # Retrieve created policy
        existing_policy = self.client.get_filter_policy_by_name(policy_name)

        # Verify the complex filter expression
        self.assertEqual(existing_policy.row_filter_policy_items[0].filter_expr, "(1 == 1) AND (2 > 1)")

        # Delete the policy
        self.client.delete_filter_policy_by_id(existing_policy.id)

    def test_access_policies_with_validity_period(self):
        # Create a policy with a validity period
        policy_name = "validity-period-access-policy"
        new_policy = AccessPolicyView(
            name=policy_name,
            description="policy with validity period",
            validity_period=ValidityPeriod(
                start_time="2023/07/01 00:00:00",
                end_time="2023/07/31 23:59:59",
                time_zone="US/Pacific"
            ),
            resources=[
                AccessPolicyResource(
                    databases=["test_db"],
                    tables=["test_tbl"],
                    columns=["*"]
                )
            ],
            allow_policy_items=[
                AccessPolicyItem(
                    accesses=[AccessType.SELECT, AccessType.UPDATE],
                    users=['{USER}'])
            ]
        )
        created_policy = self.client.create_access_policy(new_policy)

        # Verify the created policy
        self.assertEqual(created_policy.name, policy_name)

        # Retrieve created policy
        existing_policy = self.client.get_access_policy_by_name(policy_name)

        # Verify the validity period
        self.assertEqual(existing_policy.validity_period.start_time, "2023/07/01 00:00:00")
        self.assertEqual(existing_policy.validity_period.end_time, "2023/07/31 23:59:59")
        self.assertEqual(existing_policy.validity_period.time_zone, "US/Pacific")

        # Delete the policy
        self.client.delete_access_policy_by_id(existing_policy.id)

    def test_invalid_validity_period(self):
        # Attempt to create a policy with an invalid validity period (start time is after end time)
        policy_name = "invalid-validity-period-policy"
        new_policy = AccessPolicyView(
            name=policy_name,
            description="policy with invalid validity period",
            validity_period=ValidityPeriod(
                start_time="2023/07/31 23:59:59",
                end_time="2023/07/01 00:00:00",
                time_zone="US/Pacific"
            ),
            resources=[
                AccessPolicyResource(
                    databases=["test_db"],
                    tables=["test_tbl"],
                    columns=["*"]
                )
            ],
            allow_policy_items=[
                AccessPolicyItem(
                    accesses=[AccessType.SELECT, AccessType.UPDATE],
                    users=['{USER}'])
            ]
        )
        with self.assertRaises(ClientError):
            self.client.create_access_policy(new_policy)



from dataclasses import dataclass
from enum import Enum
from typing import Optional, List

from dataclasses_json import dataclass_json, LetterCase


class ResourceInclusionType(str, Enum):
    INCLUDE = "INCLUDE"
    EXCLUDE = "EXCLUDE"


class PolicyPriority(str, Enum):
    NORMAL = "NORMAL"
    OVERRIDE = "OVERRIDE"


class AccessType(str, Enum):
    ALL = "ALL"
    SELECT = "SELECT"
    UPDATE = "UPDATE"
    CREATE = "CREATE"
    DROP = "DROP"
    ALTER = "ALTER"
    READ = "READ"
    WRITE = "WRITE"
    REFRESH = "REFRESH"


class DataMaskType(str, Enum):
    MASK = "MASK"
    MASK_SHOW_LAST_4 = "MASK_SHOW_LAST_4"
    MASK_SHOW_FIRST_4 = "MASK_SHOW_FIRST_4"
    MASK_HASH = "MASK_HASH"
    MASK_NULL = "MASK_NULL"
    MASK_NONE = "MASK_NONE"
    MASK_DATE_SHOW_YEAR = "MASK_DATE_SHOW_YEAR"
    CUSTOM = "CUSTOM"


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ValidityPeriod:
    # format: yyyy/MM/dd HH:mm:ss
    start_time: str = None
    # format: yyyy/MM/dd HH:mm:ss
    end_time: str = None
    # example values: "US/Arizona", "Europe/Berlin", "Asia/Tokyo"
    time_zone: str = "Universal"


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class AccessPolicyResource:
    databases: List[str] = None
    databases_inclusion_type: ResourceInclusionType = ResourceInclusionType.INCLUDE
    tables: List[str] = None
    tables_inclusion_type: ResourceInclusionType = ResourceInclusionType.INCLUDE
    columns: List[str] = None
    columns_inclusion_type: ResourceInclusionType = ResourceInclusionType.INCLUDE


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class AccessPolicyItem:
    users: Optional[List[str]] = None
    groups: Optional[List[str]] = None
    roles: Optional[List[str]] = None
    accesses: List[AccessType] = None


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class AccessPolicyView:
    id: Optional[int] = None
    is_enabled: bool = True

    name: str = ""
    description: Optional[str] = None
    validity_period: Optional[ValidityPeriod] = None
    priority: PolicyPriority = PolicyPriority.NORMAL

    resources: List[AccessPolicyResource] = None
    allow_policy_items: Optional[List[AccessPolicyItem]] = None
    allow_exceptions: Optional[List[AccessPolicyItem]] = None
    deny_policy_items: Optional[List[AccessPolicyItem]] = None
    deny_exceptions: Optional[List[AccessPolicyItem]] = None


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class DataMaskPolicyResource:
    database: str = None
    table: str = None
    column: str = None


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class DataMaskPolicyItem:
    data_mask_type: str = None,
    data_mask_custom_expr: Optional[str] = None
    users: Optional[List[str]] = None
    groups: Optional[List[str]] = None
    roles: Optional[List[str]] = None


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class DataMaskPolicyView:
    id: Optional[int] = None
    is_enabled: bool = True

    name: str = ""
    description: Optional[str] = None
    validity_period: Optional[ValidityPeriod] = None
    priority: PolicyPriority = PolicyPriority.NORMAL

    resources: List[DataMaskPolicyResource] = None
    data_mask_policy_items: List[DataMaskPolicyItem] = None


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class RowFilterPolicyItem:
    filter_expr: str = None
    users: Optional[List[str]] = None
    groups: Optional[List[str]] = None
    roles: Optional[List[str]] = None


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class RowFilterPolicyResource:
    database: str = None
    table: str = None


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class RowFilterPolicyView:
    id: Optional[int] = None
    is_enabled: bool = True

    name: str = ""
    description: Optional[str] = None
    validity_period: Optional[ValidityPeriod] = None
    priority: PolicyPriority = PolicyPriority.NORMAL

    resources: List[RowFilterPolicyResource] = None
    row_filter_policy_items: List[RowFilterPolicyItem] = None



import os
from distutils.core import setup

package_name = "iomete_sdk"
package_version = "2.0.0"

description = """IOMETE SDK for Python."""

# pull long description from README
this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, "README.md"), "r", encoding="utf8") as f:
    long_description = f.read()

setup(
    name=package_name,
    version=package_version,
    license='Apache License 2.0',
    description=description,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='IOMETE',
    author_email='vusal@iomete.com',
    url='https://github.com/iomete/iomete-sdk',
    keywords=['iomete', 'sdk', 'spark-job', 'data-security-api'],
    extras_require={
        'dev': ['pytest']
    },
    install_requires=[
        "requests==2.28.2",
        "dataclasses-json==0.5.12",
    ],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        'Topic :: Software Development :: Build Tools',
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    python_requires=">=3.7",
)



import logging
from dataclasses import dataclass

from iomete_sdk.api_utils import APIUtils

SPARK_JOB_ENDPOINT = "/api/v1/spark-jobs"


@dataclass
class SparkJobApiClient:
    logger = logging.getLogger('SparkJobApiClient')

    host: str
    api_key: str

    spark_job_endpoint: str = None
    api_utils: APIUtils = None

    def __post_init__(self):
        self.api_utils = APIUtils(api_key=self.api_key)

        self.logger.debug(f"Host: {self.host}")
        self.spark_job_endpoint = self.host + SPARK_JOB_ENDPOINT

    def create_job(self, payload: dict):
        return self.api_utils.call(method="POST", url=self.spark_job_endpoint, payload=payload)

    def update_job(self, job_id: str, payload: dict):
        return self.api_utils.call(method="PUT", url=f"{self.spark_job_endpoint}/{job_id}", payload=payload)

    def get_jobs(self):
        return self.api_utils.call(method="GET", url=self.spark_job_endpoint)

    def get_job_by_id(self, job_id: str):
        return self.api_utils.call(method="GET", url=f"{self.spark_job_endpoint}/{job_id}")

    def delete_job_by_id(self, job_id: str):
        return self.api_utils.call(method="DELETE", url=f"{self.spark_job_endpoint}/{job_id}")

    def get_job_runs(self, job_id: str):
        return self.api_utils.call(method="GET", url=f"{self.spark_job_endpoint}/{job_id}/runs")

    def submit_job_run(self, job_id: str, payload: dict):
        return self.api_utils.call(method="POST", url=f"{self.spark_job_endpoint}/{job_id}/runs", payload=payload)

    def cancel_job_run(self, job_id: str, run_id: str):
        return self.api_utils.call(method="DELETE", url=f"{self.spark_job_endpoint}/{job_id}/runs/{run_id}")

    def get_job_run_by_id(self, job_id: str, run_id: str):
        return self.api_utils.call(method="GET", url=f"{self.spark_job_endpoint}/{job_id}/runs/{run_id}")

    def get_job_run_logs(self, job_id: str, run_id: str):
        return self.api_utils.call(method="GET", url=f"{self.spark_job_endpoint}/{job_id}/runs/{run_id}/logs")

    def get_job_run_metrics(self, job_id: str, run_id: str):
        return self.api_utils.call(method="GET", url=f"{self.spark_job_endpoint}/{job_id}/runs/{run_id}/metrics")



import json
import logging
from dataclasses import dataclass

import requests


@dataclass
class ClientError(Exception):
    status: int
    content: dict

    def __str__(self):
        return self.__repr__()


class APIUtils:
    logger = logging.getLogger('APIUtils')

    def __init__(self, api_key):
        self.api_key = api_key

    def call(self, method: str, url: str, payload: dict = None):
        headers = {
            "Content-Type": "application/json",
            "X-API-TOKEN": self.api_key
        }

        try:
            response = requests.request(
                method=method,
                url=url,
                headers=headers,
                json=payload
            )
            response.raise_for_status()

            if response.status_code == 204:
                return None

            return response.json()
        except requests.exceptions.HTTPError as e:
            self.logger.error(f"HTTP Error: {e}")
            self.logger.info(f"Response content: {response.content}")

            json_content = json.loads(response.content)
            raise ClientError(status=response.status_code, content=json_content)
        except requests.exceptions.RequestException as e:
            self.logger.error(f"Request Exception: {e}")
            raise
